@@ -2,6 +2,7 @@ import os
 import time
 import markdown as md
 import sys
+import traceback
 
 from docutils.core import publish_parts
 from Page import Page
@@ -155,7 +156,7 @@ class JinjaStaticRenderer():
         new_file_path = page.get_output_path()
         new_directory = os.path.split(new_file_path)[0]
         
-
+        print "Last built at: %s, page mtime: %s" % (last_build_time, page.get_modified_time())
 
         # Force a render if the output file doesn't exist
         if not os.path.exists(new_file_path) or page.get_modified_time() >= last_build_time:
@@ -170,8 +171,9 @@ class JinjaStaticRenderer():
         try:
             template_object = env.get_template(template)
         except:
-            print "\033[91mCouldn't load template `%s`.\033[0m Check the template for errors" % (template)
-            print "Unexpected error:", sys.exc_info()[0]
+            print "\033[1;91mCouldn't parse `%s`. Check the template for errors \033[0;37m" % (template)
+            traceback.print_exc()
+            print "\033[0m"
             return [new_file_path, 0, template]
 
         referenced_templates = self.get_referenced_templates(template)
